This is an automated email from the ASF dual-hosted git repository.

slachiewicz pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/maven-clean-plugin.git

commit ed9cab9ae9fd1b237aa6f0b66c9c3501882d6308
Author: Martin Desruisseaux <[email protected]>
AuthorDate: Tue Jul 8 16:03:33 2025 +0200

    Rename `Selector` as `PathSelector` for consistency with the class in Maven 
core.
    This is in anticipation for possible replacement by a shared implementation.
---
 src/main/java/org/apache/maven/plugins/clean/Cleaner.java           | 4 ++--
 .../apache/maven/plugins/clean/{Selector.java => PathSelector.java} | 6 +++---
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/main/java/org/apache/maven/plugins/clean/Cleaner.java 
b/src/main/java/org/apache/maven/plugins/clean/Cleaner.java
index 5715981..6dd973f 100644
--- a/src/main/java/org/apache/maven/plugins/clean/Cleaner.java
+++ b/src/main/java/org/apache/maven/plugins/clean/Cleaner.java
@@ -106,7 +106,7 @@ final class Cleaner implements FileVisitor<Path> {
     private final String fastMode;
 
     @Nullable
-    private Selector selector;
+    private PathSelector selector;
 
     /**
      * Whether the base directory is excluded from the set of directories to 
delete.
@@ -205,7 +205,7 @@ final class Cleaner implements FileVisitor<Path> {
      * @throws IOException if a file/directory could not be deleted and {@code 
failOnError} is {@code true}
      */
     public void delete(@Nonnull Fileset fileset) throws IOException {
-        selector = new Selector(fileset);
+        selector = new PathSelector(fileset);
         if (selector.isEmpty()) {
             selector = null;
         }
diff --git a/src/main/java/org/apache/maven/plugins/clean/Selector.java 
b/src/main/java/org/apache/maven/plugins/clean/PathSelector.java
similarity index 99%
rename from src/main/java/org/apache/maven/plugins/clean/Selector.java
rename to src/main/java/org/apache/maven/plugins/clean/PathSelector.java
index ee84048..0a80ba1 100644
--- a/src/main/java/org/apache/maven/plugins/clean/Selector.java
+++ b/src/main/java/org/apache/maven/plugins/clean/PathSelector.java
@@ -51,7 +51,7 @@ import java.util.Set;
  * @author Benjamin Bentmann
  * @author Martin Desruisseaux
  */
-final class Selector implements PathMatcher {
+final class PathSelector implements PathMatcher {
     /**
      * Patterns which should be excluded by default, like <abbr>SCM</abbr> 
files.
      *
@@ -177,7 +177,7 @@ final class Selector implements PathMatcher {
      *
      * @param fs the user-specified configuration
      */
-    Selector(Fileset fs) {
+    PathSelector(Fileset fs) {
         includePatterns = normalizePatterns(fs.getIncludes(), false);
         excludePatterns = 
normalizePatterns(addDefaultExcludes(fs.getExcludes(), 
fs.isUseDefaultExcludes()), true);
         baseDirectory = fs.getDirectory();
@@ -360,7 +360,7 @@ final class Selector implements PathMatcher {
 
     /**
      * {@return whether there is no include or exclude filters}.
      * In such case, this {@code Selector} instance should be ignored.
      */
     boolean isEmpty() {
         return (includes.length | excludes.length) == 0;
@@ -360,7 +360,7 @@ final class Selector implements PathMatcher {
     /**
      * {@return whether there is no include or exclude filters}.
-     * In such case, this {@code Selector} instance should be ignored.
+     * In such case, this {@code PathSelector} instance should be ignored.
      */
     boolean isEmpty() {

Reply via email to